Index: src/compiler/js-inlining-heuristic.h |
diff --git a/src/compiler/js-inlining-heuristic.h b/src/compiler/js-inlining-heuristic.h |
index 87b3c864e02838313bfeb7cc1652b479af43ebbe..367e35ad625f0601121995c4d795bd9733903604 100644 |
--- a/src/compiler/js-inlining-heuristic.h |
+++ b/src/compiler/js-inlining-heuristic.h |
@@ -37,8 +37,8 @@ class JSInliningHeuristic final : public AdvancedReducer { |
struct Candidate { |
Handle<JSFunction> functions[kMaxCallPolymorphism]; |
int num_functions; |
- Node* node = nullptr; // The call site at which to inline. |
- int calls = -1; // Number of times the call site was hit. |
+ Node* node = nullptr; // The call site at which to inline. |
+ float frequency = 0.0f; // Relative frequency of this call site. |
}; |
// Comparator for candidates. |